export default {
    "index": 12,
    "lineNumber": 1,
    "column": 13,
    "message": "Comma is not permitted after the rest element"
};